---
name: Bug report
about: Help improve CEMU by filling up this report correctly
title: ''
labels: triage
assignees: ''

---
<!--Your issue will be closed unless you confirm the following (insert `x` in the
brackets if done/agreed):-->

* [ ] Did you use the latest version of CEMU from `dev` branch?
* [ ] Did you check [current and past issues](https://github.com/hugsy/cemu/issues)?
* [ ] Did you check [current and past PR](https://github.com/hugsy/cemu/pulls)?


### Step 1: Describe your environment

* Operating System / Distribution:
* Python version:
* CEMU version (installed from `pip`, `git` etc.):


### Step 2: Describe your problem

#### Steps to reproduce

1.

#### Observed Results

* What happened? This could be a description, log output, etc.


#### Expected results

* What did you expect to happen?


#### Traces

<!--
Feel free to include in this section screenshots or stack traces.
**The more info is provided, the more likely your issue will be able to be reproduced and investigated.**
-->
